@@ -1,7 +1,13 @@
 from mindee.documents import fr, us
 from mindee.documents.cropper import CropperV1, TypeCropperV1
 from mindee.documents.custom import CustomV1, TypeCustomV1
-from mindee.documents.financial import FinancialV1, TypeFinancialV1
+from mindee.documents.financial import (
+    FinancialDocumentV1,
+    FinancialV1,
+    TypeFinancialDocumentV1,
+    TypeFinancialV1,
+)
 from mindee.documents.invoice import InvoiceV3, InvoiceV4, TypeInvoiceV3, TypeInvoiceV4
 from mindee.documents.passport import PassportV1, TypePassportV1
+from mindee.documents.proof_of_address import ProofOfAddressV1, TypeProofOfAddressV1
 from mindee.documents.receipt import ReceiptV3, ReceiptV4, TypeReceiptV3, TypeReceiptV4
