@@ -1,30 +1,26 @@
 import os
-from typing import Dict, Optional
+from typing import Dict, Optional, Union
 
 import requests
 
-from mindee.inputs import InputDocument
+from mindee.input.sources import InputSource
 from mindee.logger import logger
 from mindee.versions import __version__, get_platform, python_version
 
-MINDEE_API_URL = "https://api.mindee.net/v1"
+API_KEY_ENV_NAME = "MINDEE_API_KEY"
+API_KEY_DEFAULT = ""
+
+BASE_URL_ENV_NAME = "MINDEE_BASE_URL"
+BASE_URL_DEFAULT = "https://api.mindee.net/v1"
+
+REQUEST_TIMEOUT_ENV_NAME = "MINDEE_REQUEST_TIMEOUT"
+TIMEOUT_DEFAULT = 120
+
 PLATFORM = get_platform()
 USER_AGENT = f"mindee-api-python@v{__version__} python-v{python_version} {PLATFORM}"
 
 OTS_OWNER = "mindee"
 
-INVOICE_VERSION = "3"
-INVOICE_URL_NAME = "invoices"
-
-RECEIPT_VERSION = "3"
-RECEIPT_URL_NAME = "expense_receipts"
-
-PASSPORT_VERSION = "1"
-PASSPORT_URL_NAME = "passport"
-
-BANK_CHECK_VERSION = "1"
-BANK_CHECK_URL_NAME = "bank_check"
-
 
 class Endpoint:
     """Generic API endpoint for a product."""
@@ -32,8 +28,9 @@ class Endpoint:
     owner: str
     url_name: str
     version: str
-    key_name: str
-    api_key: str = ""
+    api_key: str = API_KEY_DEFAULT
+    _request_timeout: int = TIMEOUT_DEFAULT
+    _base_url: str = BASE_URL_DEFAULT
     _url_root: str
 
     def __init__(
@@ -41,7 +38,6 @@ class Endpoint:
         owner: str,
         url_name: str,
         version: str,
-        key_name: Optional[str] = None,
         api_key: Optional[str] = None,
     ):
         """
@@ -50,19 +46,18 @@ class Endpoint:
         :param owner: owner of the product
         :param url_name: name of the product as it appears in the URL
         :param version: interface version
-        :param key_name: where to find the key in envvars
         """
         self.owner = owner
         self.url_name = url_name
         self.version = version
-        self.key_name = key_name or url_name
         if api_key:
             self.api_key = api_key
         else:
             self.set_api_key_from_env()
+        self.set_from_env()
 
         self._url_root = (
-            f"{MINDEE_API_URL}/products/{self.owner}/{self.url_name}/v{self.version}"
+            f"{self._base_url}/products/{self.owner}/{self.url_name}/v{self.version}"
         )
 
     @property
@@ -73,65 +68,81 @@ class Endpoint:
             "User-Agent": USER_AGENT,
         }
 
-    @property
-    def envvar_key_name(self) -> str:
-        """The API key name as stored in the environment."""
+    def set_from_env(self) -> None:
+        """Set various parameters from environment variables, if present."""
+        env_vars = {
+            BASE_URL_ENV_NAME: self.set_base_url,
+            REQUEST_TIMEOUT_ENV_NAME: self.set_timeout,
+        }
+        for name, func in env_vars.items():
+            env_val = os.getenv(name, "")
+            if env_val:
+                func(env_val)
+                logger.debug("Value was set from env: %s", name)
 
-        def to_envvar(name: str) -> str:
-            return name.replace("-", "_").upper()
+    def set_timeout(self, value: Union[str, int]) -> None:
+        """Set the timeout for all requests."""
+        self._request_timeout = int(value)
 
-        key_name = to_envvar(self.key_name)
-        if self.owner != OTS_OWNER:
-            key_name = f"{to_envvar(self.owner)}_{key_name}"
-        return f"MINDEE_{key_name}_API_KEY"
+    def set_base_url(self, value: str) -> None:
+        """Set the base URL for all requests."""
+        self._base_url = value
 
     def set_api_key_from_env(self) -> None:
         """Set the endpoint's API key from an environment variable, if present."""
-        env_key = os.getenv(self.envvar_key_name, "")
-        if env_key:
-            self.api_key = env_key
-            logger.debug("Set from environment: %s", self.envvar_key_name)
+        env_val = os.getenv(API_KEY_ENV_NAME, "")
+        if env_val:
+            self.api_key = env_val
+            logger.debug("API key set from environment")
 
-    def predict_request(
+    def predict_req_post(
         self,
-        input_file: InputDocument,
+        input_source: InputSource,
         include_words: bool = False,
         close_file: bool = True,
+        cropper: bool = False,
     ) -> requests.Response:
         """
-        Make a prediction request.
+        Make a request to POST a document for prediction.
 
-        :param input_file: Input object
+        :param input_source: Input object
         :param include_words: Include raw OCR words in the response
         :param close_file: Whether to `close()` the file after parsing it.
+        :param cropper: Including Mindee cropping results.
         :return: requests response
         """
-        files = {"document": input_file.read_contents(close_file)}
+        files = {"document": input_source.read_contents(close_file)}
         data = {}
         if include_words:
             data["include_mvision"] = "true"
 
+        params = {}
+        if cropper:
+            params["cropper"] = "true"
+
         response = requests.post(
             f"{self._url_root}/predict",
             files=files,
             headers=self.base_headers,
             data=data,
+            params=params,
+            timeout=self._request_timeout,
         )
         return response
 
 
 class CustomEndpoint(Endpoint):
-    def training_request(
-        self, input_file: InputDocument, close_file: bool = True
+    def training_req_post(
+        self, input_source: InputSource, close_file: bool = True
     ) -> requests.Response:
         """
-        Make a training request.
+        Make a request to POST a document for training.
 
-        :param input_file: Input object
+        :param input_source: Input object
         :return: requests response
         :param close_file: Whether to `close()` the file after parsing it.
         """
-        files = {"document": input_file.read_contents(close_file)}
+        files = {"document": input_source.read_contents(close_file)}
         params = {"training": True, "with_candidates": True}
 
         response = requests.post(
@@ -139,14 +150,86 @@ class CustomEndpoint(Endpoint):
             files=files,
             headers=self.base_headers,
             params=params,
+            timeout=self._request_timeout,
         )
         return response
 
-    def annotation_request(
+    def training_async_req_post(
+        self, input_source: InputSource, close_file: bool = True
+    ) -> requests.Response:
+        """
+        Make a request to POST a document for training without processing.
+
+        :param input_source: Input object
+        :return: requests response
+        :param close_file: Whether to `close()` the file after parsing it.
+        """
+        files = {"document": input_source.read_contents(close_file)}
+        params = {"training": True, "async": True}
+
+        response = requests.post(
+            f"{self._url_root}/predict",
+            files=files,
+            headers=self.base_headers,
+            params=params,
+            timeout=self._request_timeout,
+        )
+        return response
+
+    def document_req_get(self, document_id: str) -> requests.Response:
+        """
+        Make a request to GET annotations for a document.
+
+        :param document_id: ID of the document
+        """
+        params = {
+            "include_annotations": True,
+            "include_candidates": True,
+            "global_orientation": True,
+        }
+        response = requests.get(
+            f"{self._url_root}/documents/{document_id}",
+            headers=self.base_headers,
+            params=params,
+            timeout=self._request_timeout,
+        )
+        return response
+
+    def document_req_del(self, document_id: str) -> requests.Response:
+        """
+        Make a request to DELETE a document.
+
+        :param document_id: ID of the document
+        """
+        response = requests.delete(
+            f"{self._url_root}/documents/{document_id}",
+            headers=self.base_headers,
+            timeout=self._request_timeout,
+        )
+        return response
+
+    def documents_req_get(self, page_n: int = 1) -> requests.Response:
+        """
+        Make a request to GET info on all documents.
+
+        :param page_n: Page number
+        """
+        params = {
+            "page": page_n,
+        }
+        response = requests.get(
+            f"{self._url_root}/documents",
+            headers=self.base_headers,
+            params=params,
+            timeout=self._request_timeout,
+        )
+        return response
+
+    def annotations_req_post(
         self, document_id: str, annotations: dict
     ) -> requests.Response:
         """
-        Make an annotation request.
+        Make a request to POST annotations for a document.
 
         :param document_id: ID of the document to annotate
         :param annotations: Annotations object
@@ -156,48 +239,49 @@ class CustomEndpoint(Endpoint):
             f"{self._url_root}/documents/{document_id}/annotations",
             headers=self.base_headers,
             json=annotations,
+            timeout=self._request_timeout,
+        )
+        return response
+
+    def annotations_req_put(
+        self, document_id: str, annotations: dict
+    ) -> requests.Response:
+        """
+        Make a request to PUT annotations for a document.
+
+        :param document_id: ID of the document to annotate
+        :param annotations: Annotations object
+        :return: requests response
+        """
+        response = requests.put(
+            f"{self._url_root}/documents/{document_id}/annotations",
+            headers=self.base_headers,
+            json=annotations,
+            timeout=self._request_timeout,
+        )
+        return response
+
+    def annotations_req_del(self, document_id: str) -> requests.Response:
+        """
+        Make a request to DELETE annotations for a document.
+
+        :param document_id: ID of the document to annotate
+        :return: requests response
+        """
+        response = requests.delete(
+            f"{self._url_root}/documents/{document_id}/annotations",
+            headers=self.base_headers,
+            timeout=self._request_timeout,
         )
         return response
 
 
-class InvoiceEndpoint(Endpoint):
-    def __init__(self, api_key: Optional[str] = None):
+class StandardEndpoint(Endpoint):
+    def __init__(self, url_name: str, version: str, api_key: Optional[str] = None):
         super().__init__(
             owner=OTS_OWNER,
-            url_name=INVOICE_URL_NAME,
-            version=INVOICE_VERSION,
-            key_name="invoice",
-            api_key=api_key,
-        )
-
-
-class ReceiptEndpoint(Endpoint):
-    def __init__(self, api_key: Optional[str] = None):
-        super().__init__(
-            owner=OTS_OWNER,
-            url_name=RECEIPT_URL_NAME,
-            version=RECEIPT_VERSION,
-            key_name="receipt",
-            api_key=api_key,
-        )
-
-
-class PassportEndpoint(Endpoint):
-    def __init__(self, api_key: Optional[str] = None):
-        super().__init__(
-            owner=OTS_OWNER,
-            url_name=PASSPORT_URL_NAME,
-            version=PASSPORT_VERSION,
-            api_key=api_key,
-        )
-
-
-class BankCheckEndpoint(Endpoint):
-    def __init__(self, api_key: Optional[str] = None):
-        super().__init__(
-            owner=OTS_OWNER,
-            url_name=BANK_CHECK_URL_NAME,
-            version=BANK_CHECK_VERSION,
+            url_name=url_name,
+            version=version,
             api_key=api_key,
         )
 
