@@ -3,39 +3,38 @@ from typing import Optional
 
 import pytz
 
-from mindee.fields.base import Field
+from mindee.fields.base import BaseField, FieldPositionMixin, TypePrediction
 
 ISO8601_DATE_FORMAT = "%Y-%m-%d"
 ISO8601_DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 
 
-class Date(Field):
+class DateField(FieldPositionMixin, BaseField):
     date_object: Optional[date] = None
-    """Date as a standard Python ``datetime.date`` object"""
-    value: Optional[str]
-    """Raw field value"""
+    """Date as a standard Python ``datetime.date`` object."""
+    value: Optional[str] = None
+    """The raw field value."""
 
     def __init__(
         self,
-        date_prediction: dict,
-        value_key: str = "iso",
+        prediction: TypePrediction,
         reconstructed: bool = False,
         page_n: Optional[int] = None,
     ):
         """
         Date field object.
 
-        :param date_prediction: Date prediction object from HTTP response
-        :param value_key: Key to use in the date_prediction dict
+        :param prediction: Date prediction object from HTTP response
         :param reconstructed: Bool for reconstructed object (not extracted in the API)
-        :param page_n: Page number for multi-page PDF
+        :param page_n: Page number for multi-page document
         """
         super().__init__(
-            date_prediction,
-            value_key=value_key,
+            prediction,
+            value_key="value",
             reconstructed=reconstructed,
             page_n=page_n,
         )
+        self._set_position(prediction)
 
         if self.value:
             try:
@@ -47,5 +46,3 @@ class Date(Field):
             except (TypeError, ValueError):
                 self.date_object = None
                 self.confidence = 0.0
-                self.value = None
-                self.bbox = []
